#!/usr/bin/env python3
#-*- coding: utf-8 -*-

from distutils.core import setup

setup(
    name='is-even',
    version='0.0.0',
    description='Return true if the given number is even.',
    author="Victor B",
    author_email="victor.bonnelle@protonmail.com",
    maintainer="Victor B",
    maintainer_email="victor.bonnelle@protonmail.com",
    url='https://github.com/victorbnl/is-even/',
    packages=[
        'is_even'
    ]
)
